pub enum SignalManagerError {
UnknownSignal(i32),
UnsupportedSignal {
signal: i32,
},
ListenAlreadyRunning,
WindowsFallbackAlreadyActive,
ListenerInit(String),
InjectorClosed,
ListenTimeout(Duration),
}Expand description
Errors returned by SignalManager operations.
Variants
UnknownSignal(i32)
A signal number was not found in the catalog.
UnsupportedSignal
The signal is known but unsupported on this platform.
ListenAlreadyRunning
Listener cannot be started more than once at a time.
WindowsFallbackAlreadyActive
Windows fallback supports only one active listener per process.
ListenerInit(String)
Signal listener backend initialization failed.
InjectorClosed
Injection channel is closed.
ListenTimeout(Duration)
Timed out waiting for the listener to start.