SignalManager

Struct SignalManager 

pub struct SignalManager { /* private fields */ }
Runtime signal manager.

Implementations

Source

impl SignalManager

pub fn new() -> SignalManager

Create a new signal manager.

pub fn handle<F>( &self, signal: i32, handler: F, ) -> Result<SignalRegistration, SignalManagerError>
where F: Fn() -> Result<(), Box<dyn Error + Send + Sync>> + Send + Sync + 'static,

Register a handler for a specific signal number.

Returns a registration guard that unregisters on drop.

pub fn on_shutdown<F>(&self, hook: F)
where F: FnOnce() -> Result<(), Box<dyn Error + Send + Sync>> + Send + 'static,

Append a shutdown hook (executed in LIFO order).

pub fn on_reload<F>(&self, hook: F)
where F: Fn() -> Result<(), Box<dyn Error + Send + Sync>> + Send + Sync + 'static,

Append a reload hook (executed in FIFO order).

pub fn enable_double_tap(&self, config: DoubleTapConfig)

Enable SIGINT double-tap behavior.

pub fn disable_double_tap(&self)

Disable SIGINT double-tap behavior.

pub fn set_endpoint_logger<F>(&self, logger: F)
where F: Fn(&SignalEndpointLogEvent) + Send + Sync + 'static,

Install a callback invoked for every processed /admin/signal request.

pub fn clear_endpoint_logger(&self)

Remove the endpoint request logger callback.

pub fn handle_admin_signal_request( &self, request: SignalEndpointRequest, ) -> SignalEndpointResponse

Process a POST /admin/signal request body.

pub fn handle_admin_signal_request_with_metadata( &self, request: SignalEndpointRequest, metadata: SignalEndpointMetadata, ) -> SignalEndpointResponse

Process a POST /admin/signal request body with HTTP-derived metadata.

pub fn supports(&self, signal: i32) -> bool

Check whether a signal is supported on the current platform.

pub fn listen(&self) -> Result<(), SignalManagerError>

Start listening for OS and injected signals.

This call blocks until SignalManager::stop is called or a shutdown signal is processed.

pub fn stop(&self)

Stop the running listener loop.